<?php

/**
 * ekartki_obrazy actions.
 *
 * @package    sam3
 * @subpackage ekartki_obrazy
 * @author     Robert Górecki
 * @version    SVN: $Id: actions.class.php 12474 2008-10-31 10:41:27Z fabien $
 */
class ekartki_obrazyActions extends myActions
{

  public function preExecute()
  {
    $perm = ($this->getUser()->checkPermission('card', 'edit') == 1) ? true : false;
    
    if (!$perm || !in_array('card', ModulPeer::getEnabled()))
    {
      $this->forwardSecure();
    }
  }

  public function executeIndex(sfWebRequest $request)
  {
    $c = $this->addSortCrit('EkartkiObrazyPeer', new Criteria());
    $c->addJoin(EkartkiObrazyPeer::GRUPA_ID, EkartkiGrupyPeer::ID);
    $c->addAscendingOrderByColumn(EkartkiGrupyPeer::NAZWA);
    $c->addDescendingOrderByColumn(EkartkiObrazyPeer::CREATED_AT);
    $this->ekartki_obrazy_list = EkartkiObrazyPeer::doSelect($c);
  }

  public function executeNew(sfWebRequest $request)
  {
    $this->form = new EkartkiObrazyForm();
  }

  public function executeCreate(sfWebRequest $request)
  {
    $this->forward404Unless($request->isMethod('post'));

    $this->form = new EkartkiObrazyForm();

    $this->processForm($request, $this->form);

    $this->setTemplate('new');
  }

  public function executeEdit(sfWebRequest $request)
  {
    $this->forward404Unless($ekartki_obrazy = EkartkiObrazyPeer::retrieveByPk($request->getParameter('id')), sprintf('Object ekartki_obrazy does not exist (%s).', $request->getParameter('id')));
    $this->form = new EkartkiObrazyForm($ekartki_obrazy);
  }

  public function executeUpdate(sfWebRequest $request)
  {
    $this->forward404Unless($request->isMethod('post') || $request->isMethod('put'));
    $this->forward404Unless($ekartki_obrazy = EkartkiObrazyPeer::retrieveByPk($request->getParameter('id')), sprintf('Object ekartki_obrazy does not exist (%s).', $request->getParameter('id')));
    $this->form = new EkartkiObrazyForm($ekartki_obrazy);

    $this->processForm($request, $this->form);

    $this->setTemplate('edit');
  }

  public function executeDelete(sfWebRequest $request)
  {
    $request->checkCSRFProtection();
    $this->getContext()->getConfiguration()->loadHelpers(array('Funkcje'));

    $this->forward404Unless($ekartki_obrazy = EkartkiObrazyPeer::retrieveByPk($request->getParameter('id')), sprintf('Object ekartki_obrazy does not exist (%s).', $request->getParameter('id')));
    $ekartki_obrazy->delete();

    $path = sfConfig::get('sf_upload_dir') . '/ekartki/obrazy/' . $ekartki_obrazy->getId();
    if (is_dir($path))
    {
      recursive_remove_directory($path);
    }

    $this->getUser()->setFlash('notice', 'Pomyślnie usunięto obraz');
    $this->redirect('ekartki_obrazy/index');
  }

  protected function processForm(sfWebRequest $request, sfForm $form)
  {
    $this->getContext()->getConfiguration()->loadHelpers(array('Funkcje'));
    $form->bind($request->getParameter($form->getName()), $request->getFiles($form->getName()));
    if ($form->isValid())
    {
      $ekartki_obrazy = $form->save();
      if ($form->isNew())
      {
        $ekartki_obrazy->setUzytkownikId($this->getUser()->getId());
        $ekartki_obrazy->save();
      }
      $id = $ekartki_obrazy->getId();
      $values = $form->getValues();

      if ($values['plik'] != NULL)
      {
        //usun poprzedni obrazek
        $path = sfConfig::get('sf_upload_dir') . '/ekartki/obrazy/' . $id;
        if (is_dir($path))
        {
          recursive_remove_directory($path, true);
        }

        if (!is_dir(sfConfig::get('sf_upload_dir') . '/ekartki/obrazy/' . $id))
        {
          mkdir(sfConfig::get('sf_upload_dir') . '/ekartki/obrazy/' . $id, 0775, true);
        }

        $file = $values['plik'];
        //generowanie miniatury
        $filename = sha1($file->getOriginalName());
        $extension = $file->getOriginalExtension();
        $ekartki_obrazy->setPlik($filename . $extension);
        $ekartki_obrazy->save();

        $img_path = sfConfig::get('sf_upload_dir') . '/ekartki/obrazy/' . $id . '/obraz_' . $filename . $extension;
        $thumb_path = sfConfig::get('sf_upload_dir') . '/ekartki/obrazy/' . $id . '/thumb_' . $filename . $extension;
        $thumb2_path = sfConfig::get('sf_upload_dir') . '/ekartki/obrazy/' . $id . '/thumb2_' . $filename . $extension;
        $ecard_path = sfConfig::get('sf_upload_dir') . '/ekartki/obrazy/' . $id . '/ecard_' . $filename . $extension;
        $file->save($img_path);


        if (is_file($img_path))
        {

          $size = UstawieniePeer::getProperties('graf_config_max'); //default 960x960
          $img = new sfImage($img_path);
          $img->thumbnail($size['x'], $size['y'], 'scale');
          $img->setQuality(100);
          $img->saveAs($img_path);

          $size = UstawieniePeer::getProperties('graf_config_thumb'); //default 212x141
          $img = new sfImage($img_path);
          $img->thumbnail($size['x'], $size['y'], 'scale');
          $img->setQuality(100);
          $img->saveAs($thumb_path);

          $size = UstawieniePeer::getProperties('graf_config_normal'); //default 100x100
          $img = new sfImage($img_path);
          $img->thumbnail($size['x'], $size['y'], 'scale');
          $img->setQuality(100);
          $img->saveAs($thumb2_path);

          $img = new sfImage($img_path);
          $img->thumbnail(300, 200, 'scale');
          $img->setQuality(100);
          $img->saveAs($ecard_path);
        }
      }
      $this->getUser()->setFlash('notice', $this->__('save_ok'));
      $this->redirect('ekartki_obrazy/edit?id=' . $ekartki_obrazy->getId());
    }
  }

}
